@@ -58,23 +58,17 @@ MODE_BINARY = 2
 MODE_TEXT = 3
 MODE_PICKLE = 4
 
-LIMITS = {
-    u'min_int': -sys.maxsize - 1,
-    u'max_int': sys.maxsize,
-    u'pragma_timeout': 60,
-}
-
 DEFAULT_SETTINGS = {
     u'statistics': 0,  # False
     u'tag_index': 0,   # False
     u'eviction_policy': u'least-recently-stored',
     u'size_limit': 2 ** 30,  # 1gb
     u'cull_limit': 10,
-    u'sqlite_synchronous': u'NORMAL',
-    u'sqlite_journal_mode': u'WAL',
     u'sqlite_cache_size': 2 ** 13,   # 8,192 pages
+    u'sqlite_journal_mode': u'WAL',
     u'sqlite_mmap_size': 2 ** 26,    # 64mb
-    u'disk_min_file_size': 2 ** 10,  # 1kb
+    u'sqlite_synchronous': u'NORMAL',
+    u'disk_min_file_size': 2 ** 15,  # 32kb
     u'disk_pickle_protocol': pickle.HIGHEST_PROTOCOL,
 }
 
@@ -128,7 +122,7 @@ class Disk(object):
         :param int pickle_protocol: pickle protocol for serialization
 
         """
-        self._dir = directory
+        self._directory = directory
         self.min_file_size = min_file_size
         self.pickle_protocol = pickle_protocol
 
@@ -169,7 +163,7 @@ class Disk(object):
             return sqlite3.Binary(key), True
         elif ((type_key is TextType)
                 or (type_key in INT_TYPES
-                    and LIMITS[u'min_int'] <= key <= LIMITS[u'max_int'])
+                    and -9223372036854775808 <= key <= 9223372036854775807)
                 or (type_key is float)):
             return key, True
         else:
@@ -207,7 +201,7 @@ class Disk(object):
 
         if ((type_value is TextType and len(value) < min_file_size)
                 or (type_value in INT_TYPES
-                    and LIMITS[u'min_int'] <= value <= LIMITS[u'max_int'])
+                    and -9223372036854775808 <= value <= 9223372036854775807)
                 or (type_value is float)):
             return 0, MODE_RAW, None, value
         elif type_value is BytesType:
@@ -269,17 +263,17 @@ class Disk(object):
             return BytesType(value) if type(value) is sqlite3.Binary else value
         elif mode == MODE_BINARY:
             if read:
-                return open(op.join(self._dir, filename), 'rb')
+                return open(op.join(self._directory, filename), 'rb')
             else:
-                with open(op.join(self._dir, filename), 'rb') as reader:
+                with open(op.join(self._directory, filename), 'rb') as reader:
                     return reader.read()
         elif mode == MODE_TEXT:
-            full_path = op.join(self._dir, filename)
+            full_path = op.join(self._directory, filename)
             with io_open(full_path, 'r', encoding='UTF-8') as reader:
                 return reader.read()
         elif mode == MODE_PICKLE:
             if value is None:
-                with open(op.join(self._dir, filename), 'rb') as reader:
+                with open(op.join(self._directory, filename), 'rb') as reader:
                     return pickle.load(reader)
             else:
                 return pickle.load(BytesIO(value))
@@ -297,7 +291,7 @@ class Disk(object):
         hex_name = codecs.encode(os.urandom(16), 'hex').decode('utf-8')
         sub_dir = op.join(hex_name[:2], hex_name[2:4])
         name = hex_name[4:] + '.val'
-        directory = op.join(self._dir, sub_dir)
+        directory = op.join(self._directory, sub_dir)
 
         try:
             os.makedirs(directory)
@@ -306,7 +300,7 @@ class Disk(object):
                 raise
 
         filename = op.join(sub_dir, name)
-        full_path = op.join(self._dir, filename)
+        full_path = op.join(self._directory, filename)
         return filename, full_path
 
 
@@ -319,7 +313,7 @@ class Disk(object):
         :param str filename: relative path to file
 
         """
-        full_path = op.join(self._dir, filename)
+        full_path = op.join(self._directory, filename)
 
         try:
             os.remove(full_path)
@@ -364,7 +358,7 @@ class Cache(object):
         except (TypeError, AssertionError):
             raise ValueError('disk must subclass diskcache.Disk')
 
-        self._dir = directory
+        self._directory = directory
         self._timeout = 60    # Use 1 minute timeout for initialization.
         self._local = threading.local()
 
@@ -376,7 +370,7 @@ class Cache(object):
                     raise EnvironmentError(
                         error.errno,
                         'Cache directory "%s" does not exist'
-                        ' and could not be created' % self._dir
+                        ' and could not be created' % self._directory
                     )
 
         sql = self._sql
@@ -502,7 +496,13 @@ class Cache(object):
     @property
     def directory(self):
         """Cache directory."""
-        return self._dir
+        return self._directory
+
+
+    @property
+    def timeout(self):
+        """SQLite connection timeout value in seconds."""
+        return self._timeout
 
 
     @property
@@ -517,7 +517,7 @@ class Cache(object):
 
         if con is None:
             con = self._local.con = sqlite3.connect(
-                op.join(self._dir, DBNAME),
+                op.join(self._directory, DBNAME),
                 timeout=self._timeout,
                 isolation_level=None,
             )
@@ -1132,13 +1132,13 @@ class Cache(object):
 
         >>> cache = Cache('/tmp/test')
         >>> _ = cache.clear()
-        >>> cache.push('first value')
+        >>> print(cache.push('first value'))
         500000000000000
         >>> cache.get(500000000000000)
         'first value'
-        >>> cache.push('second value')
+        >>> print(cache.push('second value'))
         500000000000001
-        >>> cache.push('third value', side='front')
+        >>> print(cache.push('third value', side='front'))
         499999999999999
         >>> cache.push(1234, prefix='userids')
         'userids-500000000000000'
@@ -1225,14 +1225,18 @@ class Cache(object):
         >>> cache.pull()
         (None, None)
         >>> for letter in 'abc':
-        ...     cache.push(letter)
+        ...     print(cache.push(letter))
         500000000000000
         500000000000001
         500000000000002
-        >>> cache.pull()
-        (500000000000000, 'a')
-        >>> cache.pull(side='back')
-        (500000000000002, 'c')
+        >>> key, value = cache.pull()
+        >>> print(key)
+        500000000000000
+        >>> value
+        'a'
+        >>> _, value = cache.pull(side='back')
+        >>> value
+        'c'
         >>> cache.push(1234, 'userids')
         'userids-500000000000000'
         >>> _, value = cache.pull('userids')
@@ -1351,7 +1355,7 @@ class Cache(object):
                 rows = sql(select).fetchall()
 
                 for rowid, size, filename in rows:
-                    full_path = op.join(self._dir, filename)
+                    full_path = op.join(self._directory, filename)
                     filenames.add(full_path)
 
                     if op.exists(full_path):
@@ -1377,7 +1381,7 @@ class Cache(object):
 
                 # Check file system against Cache.filename.
 
-                for dirpath, _, files in os.walk(self._dir):
+                for dirpath, _, files in os.walk(self._directory):
                     paths = [op.join(dirpath, filename) for filename in files]
                     error = set(paths) - filenames
 
@@ -1393,7 +1397,7 @@ class Cache(object):
 
                 # Check for empty directories.
 
-                for dirpath, dirs, files in os.walk(self._dir):
+                for dirpath, dirs, files in os.walk(self._directory):
                     if not (dirs or files):
                         message = 'empty directory: %s' % dirpath
                         warnings.warn(message, EmptyDirWarning)
@@ -1722,6 +1726,14 @@ class Cache(object):
         return self.reset('count')
 
 
+    def __getstate__(self):
+        return (self.directory, self.timeout, type(self.disk))
+
+
+    def __setstate__(self, state):
+        self.__init__(*state)
+
+
     def reset(self, key, value=ENOVAL):
         """Reset `key` and `value` item from Settings table.
 
@@ -1766,10 +1778,11 @@ class Cache(object):
                 # processes.
 
                 pause = 0.001
+                count = 60000  # 60 / 0.001
                 error = sqlite3.OperationalError
                 pragma = key[7:]
 
-                for _ in range(int(LIMITS[u'pragma_timeout'] / pause)):
+                for _ in range(count):
                     try:
                         args = pragma, value
                         sql('PRAGMA %s = %s' % args).fetchall()
