@@ -6,12 +6,13 @@ import sqlite3
 import time
 
 from .core import ENOVAL, DEFAULT_SETTINGS, Cache, Disk, Timeout
+from .memo import memoize
 from .persistent import Deque, Index
 
 
 class FanoutCache(object):
     "Cache that shards keys and values."
-    def __init__(self, directory, shards=8, timeout=0.025, disk=Disk,
+    def __init__(self, directory, shards=8, timeout=0.010, disk=Disk,
                  **settings):
         """Initialize cache instance.
 
@@ -87,14 +88,7 @@ class FanoutCache(object):
         :param value: value for item
 
         """
-        index = self._hash(key) % self._count
-        set_func = self._shards[index].set
-
-        while True:
-            try:
-                return set_func(key, value)
-            except Timeout:
-                continue
+        self.set(key, value, retry=True)
 
 
     def add(self, key, value, expire=None, read=False, tag=None, retry=False):
@@ -231,9 +225,11 @@ class FanoutCache(object):
         :raises KeyError: if key is not found
 
         """
-        value = self.get(key, default=ENOVAL)
+        value = self.get(key, default=ENOVAL, retry=True)
+
         if value is ENOVAL:
             raise KeyError(key)
+
         return value
 
 
@@ -326,14 +322,13 @@ class FanoutCache(object):
         :raises KeyError: if key is not found
 
         """
-        index = self._hash(key) % self._count
-        del_func = self._shards[index].__delitem__
+        deleted = self.delete(key, retry=True)
 
-        while True:
-            try:
-                return del_func(key)
-            except Timeout:
-                continue
+        if not deleted:
+            raise KeyError(key)
+
+
+    memoize = memoize
 
 
     def check(self, fix=False):
